@@ -1,7 +1,7 @@
 import sys
-import mock
-from mock import patch
-from mock import call
+from mock import (
+    patch, call, Mock
+)
 from pytest import raises
 
 import kiwi
@@ -17,9 +17,13 @@ from kiwi.exceptions import KiwiConfigFileNotFound
 
 
 class TestBootImageKiwi:
-    @patch('kiwi.boot.image.builtin_kiwi.mkdtemp')
+    @patch('kiwi.boot.image.builtin_kiwi.Temporary')
     @patch('kiwi.boot.image.builtin_kiwi.os.path.exists')
-    def setup(self, mock_exists, mock_mkdtemp):
+    @patch('kiwi.defaults.Defaults.get_boot_image_description_path')
+    def setup(self, mock_boot_path, mock_exists, mock_Temporary):
+        mock_Temporary.return_value.new_dir.return_value.name = \
+            'boot-root-directory'
+        mock_boot_path.return_value = '../data'
         Defaults.set_platform_name('x86_64')
         mock_exists.return_value = True
         description = XMLDescription('../data/example_config.xml')
@@ -27,24 +31,23 @@ class TestBootImageKiwi:
             description.load()
         )
 
-        self.manager = mock.Mock()
-        self.system_prepare = mock.Mock()
-        self.setup = mock.Mock()
-        self.profile = mock.Mock()
+        self.manager = Mock()
+        self.system_prepare = Mock()
+        self.setup = Mock()
+        self.profile = Mock()
         self.profile.dot_profile = dict()
-        self.system_prepare.setup_repositories = mock.Mock(
+        self.system_prepare.setup_repositories = Mock(
             return_value=self.manager
         )
-        kiwi.boot.image.builtin_kiwi.SystemPrepare = mock.Mock(
+        kiwi.boot.image.builtin_kiwi.SystemPrepare = Mock(
             return_value=self.system_prepare
         )
-        kiwi.boot.image.builtin_kiwi.SystemSetup = mock.Mock(
+        kiwi.boot.image.builtin_kiwi.SystemSetup = Mock(
             return_value=self.setup
         )
-        kiwi.boot.image.builtin_kiwi.Profile = mock.Mock(
+        kiwi.boot.image.builtin_kiwi.Profile = Mock(
             return_value=self.profile
         )
-        mock_mkdtemp.return_value = 'boot-root-directory'
         self.boot_image = BootImageKiwi(
             self.xml_state, 'some-target-dir'
         )
@@ -54,9 +57,10 @@ class TestBootImageKiwi:
         self.boot_image.include_file('/root/a')
 
     @patch('kiwi.defaults.Defaults.get_boot_image_description_path')
-    @patch('kiwi.boot.image.builtin_kiwi.mkdtemp')
-    def test_prepare(self, mock_mkdtemp, mock_boot_path):
-        mock_mkdtemp.return_value = 'boot-root-directory'
+    @patch('kiwi.boot.image.builtin_kiwi.Temporary')
+    def test_prepare(self, mock_Temporary, mock_boot_path):
+        mock_Temporary.return_value.new_dir.return_value.name = \
+            'boot-root-directory'
         mock_boot_path.return_value = '../data'
         self.boot_image.prepare()
         self.system_prepare.setup_repositories.assert_called_once_with(
@@ -85,14 +89,15 @@ class TestBootImageKiwi:
         self.setup.call_image_script.assert_called_once_with()
 
     @patch('os.path.exists')
-    @patch('kiwi.boot.image.builtin_kiwi.mkdtemp')
+    @patch('kiwi.boot.image.builtin_kiwi.Temporary')
     def test_prepare_no_boot_description_found(
-        self, mock_mkdtemp, mock_os_path
+        self, mock_Temporary, mock_os_path
     ):
-        mock_mkdtemp.return_value = 'boot-root-directory'
+        mock_Temporary.return_value.new_dir.return_value.name = \
+            'boot-root-directory'
         mock_os_path.return_value = False
         with raises(KiwiConfigFileNotFound):
-            self.boot_image.prepare()
+            self.boot_image.post_init()
 
     @patch('kiwi.boot.image.builtin_kiwi.ArchiveCpio')
     @patch('kiwi.boot.image.builtin_kiwi.Compress')
@@ -100,21 +105,23 @@ class TestBootImageKiwi:
     @patch('kiwi.boot.image.builtin_kiwi.Path.wipe')
     @patch('kiwi.boot.image.builtin_kiwi.DataSync')
     @patch('kiwi.boot.image.base.BootImageBase.is_prepared')
-    @patch('kiwi.boot.image.builtin_kiwi.mkdtemp')
     @patch('kiwi.boot.image.builtin_kiwi.os.chmod')
+    @patch('kiwi.boot.image.builtin_kiwi.Temporary')
     def test_create_initrd(
-        self, mock_os_chmod, mock_mkdtemp, mock_prepared, mock_sync,
-        mock_wipe, mock_create, mock_compress, mock_cpio
+        self, mock_Temporary, mock_os_chmod,
+        mock_prepared, mock_sync, mock_wipe, mock_create,
+        mock_compress, mock_cpio
     ):
-        data = mock.Mock()
+        data = Mock()
         mock_sync.return_value = data
-        mock_mkdtemp.return_value = 'temp-boot-directory'
+        mock_Temporary.return_value.new_dir.return_value.name = \
+            'temp-boot-directory'
         mock_prepared.return_value = True
         self.boot_image.boot_root_directory = 'boot-root-directory'
-        mbrid = mock.Mock()
-        mbrid.write = mock.Mock()
-        cpio = mock.Mock()
-        compress = mock.Mock()
+        mbrid = Mock()
+        mbrid.write = Mock()
+        cpio = Mock()
+        compress = Mock()
         mock_cpio.return_value = cpio
         mock_compress.return_value = compress
         self.boot_image.create_initrd(mbrid)
@@ -178,5 +185,8 @@ class TestBootImageKiwi:
         self.boot_image.cleanup()
         mock_wipe.assert_called_once_with('boot-root-directory')
 
+    def test_has_initrd_support(self):
+        assert self.boot_image.has_initrd_support() is True
+
     def teardown(self):
         sys.argv = argv_kiwi_tests
